[libdmapsharing] Start Vala-related clean up



commit e5fae437f3dddd7e1e4b8d3b4a0c34d29062b885
Author: W. Michael Petullo <mike flyn org>
Date:   Wed Dec 8 17:25:50 2010 -0600

    Start Vala-related clean up
    
    Libdmapsharing seems to have diverged from some expected naming
    conventions and this is affecting the use of libdmapsharing from Vala
    code. Rename DPAPRecordInterface and TYPE_DPAP_RECORD to make Vala
    happy. This work will continue as I attempt to make use of more of
    libdmapsharing from Vala code.
    Signed-off-by: W. Michael Petullo <mike flyn org>

 libdmapsharing/dpap-record.c |    6 +++---
 libdmapsharing/dpap-record.h |   18 +++++++++---------
 2 files changed, 12 insertions(+), 12 deletions(-)
---
diff --git a/libdmapsharing/dpap-record.c b/libdmapsharing/dpap-record.c
index fe22d9a..b4c5da6 100644
--- a/libdmapsharing/dpap-record.c
+++ b/libdmapsharing/dpap-record.c
@@ -24,7 +24,7 @@
 static gint dpap_record_init_count = 0;
 
 static void
-dpap_record_init (DPAPRecordInterface *iface)
+dpap_record_init (DPAPRecordIface *iface)
 {
 	static gboolean is_initialized = FALSE;
 
@@ -136,7 +136,7 @@ dpap_record_init (DPAPRecordInterface *iface)
 }
 
 static void
-dpap_record_finalize (DPAPRecordInterface *iface)
+dpap_record_finalize (DPAPRecordIface *iface)
 {
 	dpap_record_init_count--;
 }
@@ -148,7 +148,7 @@ dpap_record_get_type (void)
 	static GType object_type = 0;
 	if (!object_type) {
 		static const GTypeInfo object_info = {
-			sizeof(DPAPRecordInterface),
+			sizeof(DPAPRecordIface),
 			(GBaseInitFunc) dpap_record_init,
 			(GBaseFinalizeFunc) dpap_record_finalize
 		};
diff --git a/libdmapsharing/dpap-record.h b/libdmapsharing/dpap-record.h
index cea683b..cf506cc 100644
--- a/libdmapsharing/dpap-record.h
+++ b/libdmapsharing/dpap-record.h
@@ -29,11 +29,11 @@
 G_BEGIN_DECLS
 
 /**
- * TYPE_DPAP_RECORD:
+ * DPAP_TYPE_RECORD:
  *
  * The type for #DPAPRecord.
  */
-#define TYPE_DPAP_RECORD	     (dpap_record_get_type ())
+#define DPAP_TYPE_RECORD	     (dpap_record_get_type ())
 /**
  * DPAP_RECORD:
  * @o: Object which is subject to casting.
@@ -43,15 +43,15 @@ G_BEGIN_DECLS
  * certain runtime checks to identify invalid casts.
  */
 #define DPAP_RECORD(o)		     (G_TYPE_CHECK_INSTANCE_CAST ((o), \
-				      TYPE_DPAP_RECORD, DPAPRecord))
+				      DPAP_TYPE_RECORD, DPAPRecord))
 /**
  * IS_DPAP_RECORD:
  * @o: Instance to check for being a %TYPE_DPAP_RECORD.
  *
  * Checks whether a valid #GTypeInstance pointer is of type %TYPE_DPAP_RECORD.
  */
 #define IS_DPAP_RECORD(o)	     (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
-				      TYPE_DPAP_RECORD))
+				      DPAP_TYPE_RECORD))
 /**
  * DPAP_RECORD_GET_INTERFACE:
  * @o: a #DPAPRecord instance.
@@ -61,12 +61,12 @@ G_BEGIN_DECLS
  * Returns: pointer to object interface structure.
  */
 #define DPAP_RECORD_GET_INTERFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), \
-				      TYPE_DPAP_RECORD, DPAPRecordInterface))
+				      DPAP_TYPE_RECORD, DPAPRecordIface))
 
 typedef struct _DPAPRecord DPAPRecord;
-typedef struct _DPAPRecordInterface DPAPRecordInterface;
+typedef struct _DPAPRecordIface DPAPRecordIface;
 
-struct _DPAPRecordInterface {
+struct _DPAPRecordIface {
 	GTypeInterface parent;
 
 	GInputStream *  (*read)          (DPAPRecord *record, GError **err);
@@ -43,15 +43,15 @@ G_BEGIN_DECLS
 /**
  * IS_DPAP_RECORD:
- * @o: Instance to check for being a %TYPE_DPAP_RECORD.
+ * @o: Instance to check for being a %DPAP_TYPE_RECORD.
  *
@@ -43,15 +43,15 @@ G_BEGIN_DECLS
  *
- * Checks whether a valid #GTypeInstance pointer is of type %TYPE_DPAP_RECORD.
+ * Checks whether a valid #GTypeInstance pointer is of type %DPAP_TYPE_RECORD.
  */
 #define IS_DPAP_RECORD(o)	     (G_TYPE_CHECK_INSTANCE_TYPE ((o), \



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]